# python-clean-architecture

![GitHub tag](https://img.shields.io/github/v/tag/pcah/pca-errors)
[![development status](https://img.shields.io/badge/development%20status-alpha-yellow.svg)](https://pypi.org/project/pca-errors/)
[![supports](https://img.shields.io/pypi/pyversions/pca-errors)](pyproject.toml)
[![build status](https://img.shields.io/github/workflow/status/pcah/pca-errors/code-quality)](https://github.com/pcah/pca-errors/actions)
[![codecov](https://codecov.io/gh/pcah/pca-errors/branch/master/graph/badge.svg)](https://codecov.io/gh/pcah/pca-errors)

**pca-errors** is a Python library helping to define declarative, parametrizable & [L10n](https://en.wikipedia.org/wiki/Language_localisation)-independent error classes.

**pca-errors** is a part of the Clean Architecture toolset, developed under [*python-clean-architecture*](https://github.com/pcah/python-clean-architecture) project.

<!-- markdownlint-disable-next-line MD001 -->
#### Development Status  (Stage 3 - Alpha Status)

For details, look at our [ROADMAP](https://github.com/pcah/pca-errors/tree/master/ROADMAP.md).

#### Get It Now

```bash
$ pip install -U pca-errors
```

#### Quickstart

[TBDL]

#### Documentation

You can look at our [docs](https://github.com/pcah/pca-errors/tree/master/docs/).
